==> haskell-word-wrap-0.4.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: word-wrap
version: 0.4.1
id: word-wrap-0.4.1-CuXd26GHDvb8j3WnRVY93Q
key: word-wrap-0.4.1-CuXd26GHDvb8j3WnRVY93Q
license: BSD3
copyright: 2017 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/word-wrap/
synopsis: A library for word-wrapping
description:
    A library for wrapping long lines of text.
category: Text
author: Jonathan Daugherty
exposed: True
indefinite: False
exposed-modules:
    Text.Wrap
abi: 3180f393e882dbb9662a0f72cecac0bc
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/word-wrap-0.4.1
hs-libraries: HSword-wrap-0.4.1-CuXd26GHDvb8j3WnRVY93Q
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html: /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.4.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: word-wrap
version: 0.4.1
id: word-wrap-0.4.1-I7yzDecLQFf7GR87q3lM4s
key: word-wrap-0.4.1-I7yzDecLQFf7GR87q3lM4s
license: BSD3
copyright: 2017 Jonathan Daugherty
maintainer: cygnus@foobox.com
homepage: https://github.com/jtdaugherty/word-wrap/
synopsis: A library for word-wrapping
description:
    A library for wrapping long lines of text.
category: Text
author: Jonathan Daugherty
exposed: True
indefinite: False
exposed-modules:
    Text.Wrap
abi: c03f978d7ee6ebacc3d046a722b2350a
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/word-wrap-0.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/word-wrap-0.4.1
hs-libraries: HSword-wrap-0.4.1-I7yzDecLQFf7GR87q3lM4s
depends:
    base-4.10.1.0 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html: /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
